@@ -49,6 +49,7 @@ describe 'octavia' do
           :kombu_compression               => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
@@ -93,6 +94,7 @@ describe 'octavia' do
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
           :rabbit_quorum_queue                => true,
+          :rabbit_transient_quorum_queue      => true,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
@@ -130,6 +132,7 @@ describe 'octavia' do
           :kombu_compression               => 'gzip',
           :amqp_durable_queues             => true,
           :rabbit_quorum_queue             => true,
+          :rabbit_transient_quorum_queue   => true,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
